diff --git a/ShiftOS_TheReturn/Hacking.cs b/ShiftOS_TheReturn/Hacking.cs
index 9ace50e..04f8882 100644
--- a/ShiftOS_TheReturn/Hacking.cs
+++ b/ShiftOS_TheReturn/Hacking.cs
@@ -178,10 +178,10 @@ namespace ShiftOS.Engine
public class NaughtyDeveloperException : Exception
{
///
/// Create a new instance of the , with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotem.
///
/// The message you want to yell at the user.
- public NaughtyDeveloperException(string message) : base(message + " - FIX IT, YOU SCROTEM")
+ public NaughtyDeveloperException(string message) : base(message + " - FIX IT, YOU SCROTUM")
{
}
@@ -178,10 +178,10 @@ namespace ShiftOS.Engine
{
///
- /// Create a new instance of the , with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotem.
+ /// Create a new instance of the , with the specified message, which will cause Visual Studio to call the person who caused the exception a SCROTUM.
///
/// The message you want to yell at the user.